=============================
Sample Nexus Mechanism Driver
=============================

This sample configuration file can also be viewed in `file form
<../../_static/config-samples/ml2_nexus.conf.sample>`_.

.. literalinclude:: ../../_static/config-samples/ml2_nexus.conf.sample
